@@ -1076,6 +1076,9 @@ if PY35:
             # RT_CONSISTENT' failed!" and fail.
             disabled_tests += [
                 'test_threading.ThreadTests.test_is_alive_after_fork',
+                # This has timing constraints that are strict and do not always
+                # hold.
+                'test_selectors.PollSelectorTestCase.test_timeout',
             ]
 
     if TRAVIS:
@@ -1228,7 +1231,9 @@ if PY37:
 
     if APPVEYOR:
         disabled_tests += [
-
+            # This sometimes produces ``self.assertEqual(1, len(s.select(0))): 1 != 0``.
+            # Probably needs to spin the loop once.
+            'test_selectors.BaseSelectorTestCase.test_timeout',
         ]
 
 if PY38:
@@ -1283,17 +1288,14 @@ if OSX:
     disabled_tests += [
         # This sometimes produces OSError: Errno 40: Message too long
         'test_socket.RecvmsgIntoTCPTest.testRecvmsgIntoGenerator',
+
+        # These sometime timeout. Cannot reproduce locally.
+        'test_ftp.TestTLS_FTPClassMixin.test_mlsd',
+        'test_ftp.TestTLS_FTPClassMixin.test_retrlines_too_long',
+        'test_ftp.TestTLS_FTPClassMixin.test_storlines',
+        'test_ftp.TestTLS_FTPClassMixin.test_retrbinary_rest',
     ]
 
-    if RUNNING_ON_CI:
-
-        disabled_tests += [
-            # These sometime timeout. Cannot reproduce locally.
-            'test_ftp.TestTLS_FTPClassMixin.test_mlsd',
-            'test_ftp.TestTLS_FTPClassMixin.test_retrlines_too_long',
-            'test_ftp.TestTLS_FTPClassMixin.test_storlines',
-        ]
-
     if RESOLVER_ARES and PY38 and not RUNNING_ON_CI:
         disabled_tests += [
             # When updating to 1.16.0 this was seen locally, but not on CI.
@@ -1313,6 +1315,19 @@ if PY39:
         'test_subprocess.POSIXProcessTestTest.test_send_signal_race',
     ]
 
+if TRAVIS:
+    disabled_tests += [
+        # These tests frequently break when we try to use newer Travis CI images,
+        # due to different versions of OpenSSL being available. See above for some
+        # specific examples. Usually the tests catch up, eventually (e.g., at this writing,
+        # the 3.9b1 tests are fine on Ubuntu Bionic, but all other versions fail).
+        'test_ssl.ContextTests.test_options',
+        'test_ssl.ThreadedTests.test_alpn_protocols',
+        'test_ssl.ThreadedTests.test_default_ecdh_curve',
+        'test_ssl.ThreadedTests.test_shared_ciphers',
+
+    ]
+
 # Now build up the data structure we'll use to actually find disabled tests
 # to avoid a linear scan for every file (it seems the list could get quite large)
 # (First, freeze the source list to make sure it isn't modified anywhere)
